#include <bits/stdc++.h>

using namespace std;

#define int long long

const int INF = 1000000000000;

#define PI 3.141592653589793

// #define double long double
// const double EPS = 0.000000000000001l;

#define double long long
const double EPS = 0;

class Point {
public:
	double x, y;
	bool exists;
	Point(): x(0), y(0), exists(false) {}
	Point(double x, double y): x(x), y(y), exists(true) {}
	operator bool() const {
		return exists;
	}
	friend istream& operator>>(istream& in, Point& p) {
		p.exists = true;
		return in >> p.x >> p.y;
	}
	void clear() {
		exists = false;
		x = 0;
		y = 0;
	}
	bool operator==(Point other) const {
		return abs(x - other.x) <= EPS && abs(y - other.y) <= EPS;
	}
	bool operator!=(Point other) const {
		return !(*this == other);
	}
	bool operator<(Point other) const {
		return x == other.x ? y < other.y : x < other.x;
	}
};

class Vector {
public:
	double x, y;
	Vector(): x(0), y(0) {}
	Vector(double x, double y): x(x), y(y) {}
	Vector(Point a, Point b): x(b.x - a.x), y(b.y - a.y) {}
	Vector(Point p): x(p.x), y(p.y) {}
	double length() const {
		return sqrt(x * x + y * y);
	}
	Vector normal() const {
		return Vector{y, -x};
	}
	double operator%(Vector other) const {
		return x * other.y - y * other.x;
	}
};

class Line {
public:
	double a, b, c;
	Line(double a, double b, double c): a(a), b(b), c(c) {}
	Line(Point p1, Point p2) {
		a = p2.y - p1.y;
		b = p1.x - p2.x;
		c = -(a * p1.x + b * p1.y);
	}
	Line(Point p, Vector n) {
		a = n.x;
		b = n.y;
		c = -(n.x * p.x + n.y * p.y);
	}
	Vector normal() const {
		return Vector{a, b};
	}
	Point project(Point p) const {
		return Line(p, normal().normal()) & (*this);
	}
	Line normalize() const {
		double k = sqrt(a * a + b * b);
		if(a < 0) {
			k = -k;
		} else if(abs(a) <= EPS && b < 0) {
			k = -k;
		}
		return Line{a / k, b / k, c / k};
	}
	Point operator&(Line other) const {
		auto k = b * other.a - a * other.b;
		if(abs(k) <= EPS) {
			return Point{};
		} else {
			return Point{(c * other.b - b * other.c) / k, (a * other.c - c * other.a) / k};
		}
	}
};

class Segment {
public:
	Point a, b;
	Segment(Point a, Point b): a(a), b(b) {
	}
	Line line() const {
		return Line(a, b);
	}
	bool contains_assume_on_line(Point p) const {
		return (
			min(a.x, b.x) - EPS <= p.x && p.x <= max(a.x, b.x) + EPS && min(a.y, b.y) - EPS <= p.y && p.y <= max(a.y, b.y) + EPS
		) && p != a && p != b;
	}
	Point operator&(Segment other) const {
		auto p = line() & other.line();
		return p && contains_assume_on_line(p) && other.contains_assume_on_line(p) ? p : Point{};
	}
	Point operator&(Line l) const {
		auto p = line() & l;
		return p && contains_assume_on_line(p) ? p : Point{};
	}
};

vector<Point> convex_hull(vector<Point> points) {
	double minx = 0;
	double miny = 0;
	for(auto p: points) {
		minx = min(minx, p.x);
		miny = min(miny, p.y);
	}

	for(Point &p: points) {
		p.x -= minx - 1;
		p.y -= miny - 1;
	}

	sort(points.begin(), points.end(), [](Point a, Point b) {
		return Vector(a) % Vector(b) > 0;
	});

	vector<Point> above, below;
	above.push_back(points[0]);
	below.push_back(points[0]);

	Vector v(points[0], points.back());
	for(int i = 1; i < points.size(); i++) {
		if(v % Vector(points[0], points[i]) <= 0) {
			above.push_back(points[i]);
		}
		if(v % Vector(points[0], points[i]) >= 0) {
			below.push_back(points[i]);
		}
	}

	vector<Point> above_ch;
	for(Point p: above) {
		while(
			above_ch.size() >= 2 &&
			(
				Vector(above_ch[above_ch.size() - 2], above_ch.back()) %
				Vector(above_ch.back(), p)
			) <= 0
		) {
			above_ch.pop_back();
		}
		above_ch.push_back(p);
	}

	vector<Point> below_ch;
	for(Point p: below) {
		while(
			below_ch.size() >= 2 &&
			(
				Vector(below_ch[below_ch.size() - 2], below_ch.back()) %
				Vector(below_ch.back(), p)
			) >= 0
		) {
			below_ch.pop_back();
		}
		below_ch.push_back(p);
	}

	vector<Point> ch = above_ch;
	ch.pop_back();
	for(auto it = below_ch.rbegin(); it != below_ch.rend(); ++it) {
		ch.push_back(*it);
	}
	ch.pop_back();

	for(Point &p: ch) {
		p.x += minx - 1;
		p.y += miny - 1;
	}

	return ch;
}

bool bad[300][300];
signed main() {
	int n;
	cin >> n;
	vector<Point> pp(n);
	for (int i = 0; i < n; i++) {
		cin >> pp[i];
	}
	auto arr1 = convex_hull(pp);
	vector<pair<int, int>> all;
	if((pp.size() - arr1.size()) % 2 == 1) {
		cout << 2 << endl;
		int i, j;
		cin >> i >> j;
		i--;
		j--;
		all.emplace_back(i, j);
		bad[i][j] = bad[j][i] = true;
	} else {
		cout << 1 << endl;
	}
	while (true) {
		bool omg = false;
		for (int i = 0; i < n; i++) {
			if (omg) {
				break;
			}
			for (int j = 0; j < i; j++) {
				if (bad[i][j]) {
					continue;
				}
				bool good = true;
				for (auto p: all) {
					if(Segment(pp[i], pp[j]) & Segment(pp[p.first], pp[p.second])) {
						good = false;
						break;
					}
				}
				bad[i][j] = true;
				bad[j][i] = true;
				if (good) {
					omg = true;
					all.emplace_back(i, j);
					cout << i + 1 << " " << j + 1 << endl;
					break;
				}
			}
		}
		int i1, j1;
		cin >> i1 >> j1;
		if(i1 == 0 && j1 == 0) return 0;
		i1--; j1--;
		all.emplace_back(i1, j1);
		bad[i1][j1] = true;
		bad[j1][i1] = true;
	}
}