#include <bits/stdc++.h>
#define pb emplace_back
#define fi first
#define se second

using namespace std;
const long double eps = 1e-4;
typedef long long ll;

struct point {
    long long x, y;

    point operator + (const point &b) {
        point c = {x + b.x, y + b.y};
        return c;
    }

    point operator - (const point &b) {
        point c = {x - b.x, y - b.y};
        return c;
    }

    double operator * (const point &b) {
        return x * b.x + y * b.y;
    }

    double operator ^ (const point &b) {
        return x * b.y - y * b.x;
    }

    bool operator == (const point &b) {
        return (max(abs(x - b.x), abs(y - b.y)) < eps);
    }

    bool line(const point &a, const point &b) {
        point v1 = {a.x - x, a.y - y};
        point v2 = {b.x - x, b.y - y};

        return((v1 ^ v2) == 0);
    }

    bool between(const point &a, const point &b) {
        point v1 = {a.x - x, a.y - y};
        point v2 = {b.x - x, b.y - y};

        assert((v1 ^ v2) == 0);
        return ((v1 * v2) <= 0);
    }

    bool in_angle(point a, point o, point b) {
        point p = {x, y};

        a = a - o;
        b = b - o;
        p = p - o;

        if ((a ^ b) < 0)
            swap(a, b);

        return ((a ^ p) >= 0 && (p ^ b) >= 0);
    }

    bool in_convex(vector <point> &v) {
        if (in_angle(v[v.size() - 1], v[0], v[1]) == false)
            return false;

        point p = {x, y};

        int l = 1, r = v.size();
        while (r - l > 1) {
            int m = (l + r) / 2;
            if (((v[m] - v[0]) ^ (p - v[0])) > 0)
                l = m;
            else
                r = m;
        }

        return (((v[l + 1] - v[l]) ^ (p - v[l])) >= 0);
    }

    double length() {
        return sqrt(x * x + y * y);
    }

    long long sqrlen() {
        return (x * x + y * y);
    }

    double dist(point a, point b) {
        point v1 = {a.x - x, a.y - y};
        point v2 = {b.x - x, b.y - y};

        return abs((v1 ^ v2) / (a - b).length());
    }

    double seg_dist(point a, point b) {
        point v1 = {a.x - x, a.y - y};
        point v2 = {b.x - x, b.y - y};
        point ab = a - b;

        if (a == b)
            return v1.length();

        if (v1.sqrlen() > ab.sqrlen() + v2.sqrlen())
            return v2.length();
        if (v2.sqrlen() > ab.sqrlen() + v1.sqrlen())
            return v1.length();
        return dist(a, b);
    }
};

int sign_dot(point a, point b) {
    if (a * b > 0)
        return 1;
    if (a * b < 0)
        return -1;
    return 0;
}

int sign_cross(point a, point b) {
    if ((a ^ b) > 0)
        return 1;
    if ((a ^ b) < 0)
        return -1;
    return 0;
}

int sign(double x) {
    if (x > 0)
        return 1;
    if (x < 0)
        return -1;
    return 0;
}

point p_in() {
    long long x, y; cin >> x >> y;
    point p = {x, y};
    return p;
}

void p_out(point X) {
    cout << fixed << setprecision(9) << X.x << ' ' << X.y << endl;
}

bool seg_cross(point A, point B, point C, point D) {
    if (A == B) {
        if (!A.line(C, D))
            return false;
    }

    if (C == D) {
        if (!C.line(A, B))
            return false;
    }

    if (A.line(C, D) && B.line(C, D)) {
        if (A.between(C, D) || B.between(C, D) || C.between(A, B) || D.between(A, B))
            return true;
        return false;
    }

    if (sign_cross(D - C, A - C) * sign_cross(D - C, B - C) <= 0 && sign_cross(B - A, C - A) * sign_cross(B - A, D - A) <= 0)
        return true;
    return false;
}

double abs_angle(point a, point b) {
    return abs(atan2(a ^ b, a * b));
}

long long S2(vector <point> v) {
    v.pb(v[0]);
    long long ans = 0;
    for (int i = 0; i < (int)v.size() - 1; i++)
        ans += (v[i] ^ v[i + 1]);
    return abs(ans);
}

vector <point> ccw(vector <point> v) {
    sort(v.begin(), v.end(), [](point a, point b) {
        if (abs(a.x - b.x) < eps)
            return (a.y < b.y);
        return (a.x < b.x);
    });

    v.resize(unique(v.begin(), v.end(), [](point a, point b) {
        return (max(abs(a.x - b.x), abs(a.y - b.y)) < eps);
    }) - v.begin());

    point LB = v[0];
    for (point &i : v)
        i = i - LB;

    sort(v.begin() + 1, v.end(), [](point a, point b) {
        if ((a ^ b) == 0)
            return (a.sqrlen() < b.sqrlen());
        return ((a ^ b) > 0);
    });

    for (point &i : v)
        i = i + LB;

    return v;
}

vector <point> convex_hull(vector <point> v) {
    v = ccw(v);
    int n = v.size();

    point LB = v[0];
    for (int i = n - 1; i > -1; i--)
        v[i] = v[i] - LB;

    sort(v.begin() + 1, v.end(), [](point a, point b) {
        if ((a ^ b) == 0)
            return (a.length() < b.length());
        return ((a ^ b) > 0);
    });

//    cout << "sorted" << endl;
//    for (point i : v)
//        p_out(i);
//    cout << endl;

    vector <point> hull;
    for (int i = 0; i < (int)v.size(); i++) {
        while (hull.size() >= 2) {
            if (((v[i] - hull[hull.size() - 2]) ^ (hull.back() - hull[hull.size() - 2])) >= 0)
                hull.pop_back();
            else break;
        }
        hull.pb(v[i]);
    }

    for (point &p : hull)
        p = p + LB;

    return hull;
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0); cout.tie(0);

    int n; cin >> n;
    vector <point> p;
    for (int i = 0; i < n; i++)
        p.pb(p_in());

    vector <point> h = convex_hull(p);
    ll f = 2 * n - h.size() - 1;
    ll e = (3 * f + h.size() - 3) / 2;
    //cout << f << ' ' << h.size() << ' ' << 3 * f + h.size() - 3 << ' ' << e << endl;

    vector <pair <int, int>> s;
    for (int i = 0; i < n; i++) {
        for (int j = i + 1; j < n; j++)
            s.pb(i, j);
    }

    if (e % 2)
        cout << "1" << endl;
    else
        cout << "2" << endl;

    for (int i = 0; true; i++) {
        if (i % 2 != e % 2) {
            cout << s.back().fi + 1 << ' ' << s.back().se + 1 << endl;
            s.pop_back();
        } else {
            int x, y;
            cin >> x >> y;
            if (x == 0 && y == 0) return 0;
            x--; y--;
            if (x > y)
                swap(x, y);

            vector <pair <int, int>> s1;
            for (pair <int, int> q : s) {
                if (q == make_pair(x, y)) continue;
                if (seg_cross(p[q.fi], p[q.se], p[x], p[y]) && x != q.fi && y != q.se && x != q.se && y != q.fi) continue;
                s1.pb(q);
            }
            s = s1;
//            cout << "s1" << endl;
//            for (pair <int, int> q : s) {
//                cout << q.fi << ' ' << q.se << endl;
//            }
//            cout << endl;
        }
    }
}
