#include <bits/stdc++.h>
#define int long long 
using namespace std;


struct point {
    int x, y;

    point(int x = 0, int y = 0) : x(x), y(y) {};

    bool operator<(const point b) const
    {
        return pair<int, int>{ x, y } < pair<int, int>{b.x, b.y};
    }

    bool operator>(const point b) const
    {
        return pair<int, int>{ x, y } > pair<int, int>{b.x, b.y};
    }


    bool operator ==(const point other) const {
        return x == other.x && y == other.y;
    }
};


point operator -(point a, point b) {
    return { a.x - b.x, a.y - b.y };
}

int vprod(point a, point b) {
    return a.x * b.y - a.y * b.x;
}


int sprod(point a, point b) {
    return a.x * b.x + a.y * b.y;
}


int convex_hull(vector<point> P) {
    int n = P.size();
    int min_idx = min_element(P.begin(), P.end()) - P.begin();
    swap(P[0], P[min_idx]);
    sort(P.begin() + 1, P.end(), [&](const point& p, const point& q) {
        if (vprod(p - P[0], q - P[0]) != 0) {
            return vprod(p - P[0], q - P[0]) > 0;
        }
        else {
            return sprod(p - P[0], p - P[0]) < sprod(q - P[0], q - P[0]);
        }
    });

    vector<point> res{ P[0] };
    for (int i = 1; i < n; ++i)
    {
        while (res.size() > 1 && vprod(res[res.size() - 1] - res[res.size() - 2], P[i] - res[res.size() - 1]) < 0)
            res.pop_back();

        res.push_back(P[i]);
    }

    return res.size();
}



struct line {
    point p1, p2;


    bool operator ==(line other) {
        return make_pair(min(p1, p2), max(p1, p2)) == make_pair(min(other.p1, other.p2), max(other.p1, other.p2));
    }
};


bool intersect(line l1, line l2) {

    int a = vprod((l1.p2 - l1.p1), (l2.p1 - l1.p1)), b = vprod((l1.p2 - l1.p1), (l2.p2 - l1.p1));
    if ((a >= 0 && b >= 0) || (a <= 0 && b <= 0)) return false;
    swap(l1, l2);
    a = vprod((l1.p2 - l1.p1), (l2.p1 - l1.p1)); b = vprod((l1.p2 - l1.p1), (l2.p2 - l1.p1));
    if ((a >= 0 && b >= 0) || (a <= 0 && b <= 0)) return false;

    return true;
}


vector<line> L;
map<point, int> f;




void make_turn(line l) {
    vector<line> L_;
    for (auto el : L) {
        if (el == l) {
            continue;
        }
        if (!intersect(el, l)) {
            L_.push_back(el);
        }
    }
    L = L_;
}


line get() {
    return L.front();
}


void Q(line l) {
    cout << f[l.p1] << " " << f[l.p2] << endl;
    make_turn(l);
}



signed main()
{
    int n;
    cin >> n;
    vector<point> P(n);
    for (int i = 0; i < n; ++i) {
        cin >> P[i].x >> P[i].y;
        f[P[i]] = i + 1;
    }
    for (int i = 0; i < n; ++i)
        for (int j = i + 1; j < n; ++j)
            L.push_back({ P[i], P[j] });
   
    int m = convex_hull(P);

    int e = (3 * n - m - 3);

    if (e % 2)
    {
        cout << 1 << endl;
        line l = get();
        Q(l);
    }
    else
    {
        cout << 2 << endl;
    }

    while (true)
    {
        int x, y; cin >> x >> y;
        if (x == 0 && y == 0) break;
        --x; --y;
        make_turn({ P[x], P[y] });
        Q(get());
    }

    return 0;
}